
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: Dominos, IsAddOnLoaded, next

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Integration Dominos")
local Masque = LibStub('Masque', true)

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	if not IsAddOnLoaded("Dominos") then
		 self:RegisterEvent("ADDON_LOADED")
		 return
	end

	local ButtonThemer = Dominos:GetModule("ButtonThemer")

	if not self:IsHooked(ButtonThemer, "Register") then
		self:SecureHook(ButtonThemer, "Register", "StyleButtons")
	end

	self:RegisterMessage("SIXUI_CLUTTER_STATE_CHANGED")
	self:StyleButtons()
end

function M:OnDisable()
	self:SIXUI_CLUTTER_STATE_CHANGED(nil, false)
	self:UnstyleButtons()
end

-- Apply SixUI's style to all buttons.
function M:StyleButtons()
	if Masque then
		for _, group in next, Masque:Group("Dominos").SubList do
			for button in next, group.Buttons do
				self:StyleButton(button)
			end
		end
	end
end

-- Apply SixUI's style to a button.
function M:StyleButton(button)
	if button then
		B:CreateBorder(button, C.BORDER_PADDING)
	end
end

-- Remove SixUI's style from all buttons.
function M:UnstyleButtons()
	if Masque then
		for _, group in next, Masque:Group("Dominos").SubList do
			for button in next, group.Buttons do
				B:RemoveBorder(button)
			end
		end
	end
end

-- Show binding text if it hasn't been set by the player.
function M:ShowBindingText(state)
	if (state and not Dominos:ShowBindingText()) or (not state and self.showBindingText) then
		self.showBindingText = state
		Dominos:SetShowBindingText(state)
	end
end

-- Show macro text if it hasn't been set by the player.
function M:ShowMacroText(state)
	if (state and not Dominos:ShowMacroText()) or (not state and self.showMacroText) then
		self.showMacroText = state
		Dominos:SetShowMacroText(state)
	end
end

-------------------------------------------------------------------------------
-- Events
-------------------------------------------------------------------------------

function M:ADDON_LOADED(event, name)
	if name == "Dominos" then
		self:UnregisterEvent("ADDON_LOADED")
		self:OnEnable()
	end
end

function M:SIXUI_CLUTTER_STATE_CHANGED(event, state)
	if self.config.showBindingText then
		self:ShowBindingText(state)
	end

	if self.config.showMacroText then
		self:ShowMacroText(state)
	end
end
